Oly - CLI
==========

Oly is a command line tool that allows developers to manage services. 

Supported Platforms
-------------------

Oly has been tested and is known to run on Linux (Ubuntu), Mac OS X
(10.4, 10.5, 10.6), and Solaris (10 for Intel) and FreeBSD 6.1.  It will
likely work fine on most UNIX systems.

Windows not tested yet...

Oly is intended to work on Python 3 version 3.* or later
and on Python 2 version >2.7.

Documentation
-------------

--

Reporting Bugs, and Viewing the Source Repository
---------------------------------------------------------------

Please report bugs in the [Github issue tracker](https://github.com/glikaj/oly/issues)

You can view the source repository for oly via [https://github.com/glikaj/oly](https://github.com/glikaj/oly)


Contributing
------------

If you'd like to contribute to oly directly, please contact me directly
